==> dif-database-repository-2.1.7-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/PersistentForm.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * PersistentForm
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class PersistentForm extends AbstractBeanAttributes implements java.io.Serializable {

    /** PersistentForm attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** formId column */
        public static final String FORMID = "formId";
        /** disabledFields column */
        public static final String DISABLEDFIELDS = "disabledFields";
        /** fieldDefs column */
        public static final String FIELDDEFS = "fieldDefs";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("formId");
            list.add("disabledFields");
            list.add("fieldDefs");

            return list;
        }
    }

    /** PersistentForm FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("formId".equalsIgnoreCase(attributeName))
            return formId;
        if ("disabledFields".equalsIgnoreCase(attributeName))
            return disabledFields;
        if ("fieldDefs".equalsIgnoreCase(attributeName))
            return fieldDefs;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("formId".equalsIgnoreCase(attributeName))
            formId = (String)attributeValue;
        if ("disabledFields".equalsIgnoreCase(attributeName))
            disabledFields = (String)attributeValue;
        if ("fieldDefs".equalsIgnoreCase(attributeName))
            fieldDefs = (String)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** formId private attribute */
    private String formId;

    /** disabledFields private attribute */
    private String disabledFields;

    /** fieldDefs private attribute */
    private String fieldDefs;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public PersistentForm() {
    }

	/** 
	 * minimal constructor
	 *
     * @param formId
    }
	 */
    public PersistentForm(String formId) {
        this.formId = formId;
    }

    /**
     * full constructor
	 *
     * @param formId
     * @param disabledFields
     * @param fieldDefs
     */
    public PersistentForm(String formId, String disabledFields, String fieldDefs) {
        this.formId = formId;
        this.disabledFields = disabledFields;
        this.fieldDefs = fieldDefs;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return PersistentForm modified instance
     */
    public PersistentForm setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * formId getter method
     *
     * @return formId method
     */
    public String getFormId() {
        return this.formId;
    }
    
    /**       
     * formId setter method
     *
     * @param formId
     *
     * @return PersistentForm modified instance
     */
    public PersistentForm setFormId(String formId) {
        this.formId = formId;
        
        return this;
    }
    /**       
     * disabledFields getter method
     *
     * @return disabledFields method
     */
    public String getDisabledFields() {
        return this.disabledFields;
    }
    
    /**       
     * disabledFields setter method
     *
     * @param disabledFields
     *
     * @return PersistentForm modified instance
     */
    public PersistentForm setDisabledFields(String disabledFields) {
        this.disabledFields = disabledFields;
        
        return this;
    }
    /**       
     * fieldDefs getter method
     *
     * @return fieldDefs method
     */
    public String getFieldDefs() {
        return this.fieldDefs;
    }
    
    /**       
     * fieldDefs setter method
     *
     * @param fieldDefs
     *
     * @return PersistentForm modified instance
     */
    public PersistentForm setFieldDefs(String fieldDefs) {
        this.fieldDefs = fieldDefs;
        
        return this;
    }

    /**
     * Creates a String representation of the PersistentForm object
     *
     * @return the compiled String
     */
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("formId").append("='").append(getFormId()).append("' ");			
        buffer.append("disabledFields").append("='").append(getDisabledFields()).append("' ");			
        buffer.append("fieldDefs").append("='").append(getFieldDefs()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the PersistentForm object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(PersistentForm other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("formId".equalsIgnoreCase(attributeName))
        	this.formId = attributeValue;

        if ("disabledFields".equalsIgnoreCase(attributeName))
        	this.disabledFields = attributeValue;

        if ("fieldDefs".equalsIgnoreCase(attributeName))
        	this.fieldDefs = attributeValue;

    }


}

==> dif-database-repository-2.1.9-12-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/PersistentForm.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import java.util.ArrayList;
import java.util.List;
import pt.digitalis.dif.model.utils.AbstractBeanAttributes;

/**
 * PersistentForm Generated on ORM Generator DIF build process for the Model layer
 */
@SuppressWarnings("serial")
public class PersistentForm extends AbstractBeanAttributes implements java.io.Serializable {

    /** PersistentForm attributes enumeration */
    public static class Fields {

        /** id column */
        public static final String ID = "id";
        /** formId column */
        public static final String FORMID = "formId";
        /** disabledFields column */
        public static final String DISABLEDFIELDS = "disabledFields";
        /** fieldDefs column */
        public static final String FIELDDEFS = "fieldDefs";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("formId");
            list.add("disabledFields");
            list.add("fieldDefs");

            return list;
        }
    }

    /** PersistentForm FK class */
    public static class FK {
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    protected Object getAttributeNoGraphNavigation(String attributeName)
    {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("formId".equalsIgnoreCase(attributeName))
            return formId;
        if ("disabledFields".equalsIgnoreCase(attributeName))
            return disabledFields;
        if ("fieldDefs".equalsIgnoreCase(attributeName))
            return fieldDefs;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue)
    {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long) attributeValue;
        if ("formId".equalsIgnoreCase(attributeName))
            formId = (String) attributeValue;
        if ("disabledFields".equalsIgnoreCase(attributeName))
            disabledFields = (String) attributeValue;
        if ("fieldDefs".equalsIgnoreCase(attributeName))
            fieldDefs = (String) attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** formId private attribute */
    private String formId;

    /** disabledFields private attribute */
    private String disabledFields;

    /** fieldDefs private attribute */
    private String fieldDefs;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    public synchronized static List<String> getPKFieldList()
    {
        if (pkFieldList == null)
        {
            pkFieldList = new ArrayList<String>();
            pkFieldList.add("id");
        }

        return pkFieldList;
    }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
    public static String getPKFieldListAsString()
    {
        StringBuffer buffer = new StringBuffer();

        for (int i = 0; i < getPKFieldList().size(); i++)
        {
            if (i != 0)
                buffer.append(",");

            buffer.append(getPKFieldList().get(i));
        }

        return buffer.toString();
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
    @Override
    public String getAttributeAsString(String attributeName)
    {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else
        {
            return value.toString().trim();
        }
    }

    // Constructors

    /**
     * default constructor
     */
    public PersistentForm()
    {}

    /**
     * minimal constructor
     *
     * @param formId
     *            }
     */
    public PersistentForm(String formId)
    {
        this.formId = formId;
    }

    /**
     * full constructor
     *
     * @param formId
     * @param disabledFields
     * @param fieldDefs
     */
    public PersistentForm(String formId, String disabledFields, String fieldDefs)
    {
        this.formId = formId;
        this.disabledFields = disabledFields;
        this.fieldDefs = fieldDefs;
    }

    // Property accessors

    /**
     * id getter method
     *
     * @return id method
     */
    public Long getId()
    {
        return this.id;
    }

    /**
     * id setter method
     *
     * @param id
     * @return PersistentForm modified instance
     */
    public PersistentForm setId(Long id)
    {
        this.id = id;

        return this;
    }

    /**
     * formId getter method
     *
     * @return formId method
     */
    public String getFormId()
    {
        return this.formId;
    }

    /**
     * formId setter method
     *
     * @param formId
     * @return PersistentForm modified instance
     */
    public PersistentForm setFormId(String formId)
    {
        this.formId = formId;

        return this;
    }

    /**
     * disabledFields getter method
     *
     * @return disabledFields method
     */
    public String getDisabledFields()
    {
        return this.disabledFields;
    }

    /**
     * disabledFields setter method
     *
     * @param disabledFields
     * @return PersistentForm modified instance
     */
    public PersistentForm setDisabledFields(String disabledFields)
    {
        this.disabledFields = disabledFields;

        return this;
    }

    /**
     * fieldDefs getter method
     *
     * @return fieldDefs method
     */
    public String getFieldDefs()
    {
        return this.fieldDefs;
    }

    /**
     * fieldDefs setter method
     *
     * @param fieldDefs
     * @return PersistentForm modified instance
     */
    public PersistentForm setFieldDefs(String fieldDefs)
    {
        this.fieldDefs = fieldDefs;

        return this;
    }

    /**
     * Creates a String representation of the PersistentForm object
     *
     * @return the compiled String
     */
    public String toString()
    {
        StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");
        buffer.append("formId").append("='").append(getFormId()).append("' ");
        buffer.append("disabledFields").append("='").append(getDisabledFields()).append("' ");
        buffer.append("fieldDefs").append("='").append(getFieldDefs()).append("' ");
        buffer.append("]");

        return buffer.toString();
    }

    /**
     * Compares the String representation of the PersistentForm object
     *
     * @param other
     *            The object to compare to
     * @return true of the objects are equal
     */
    public boolean equals(PersistentForm other)
    {
        return this.toString().equals(other.toString());
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue)
    {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("formId".equalsIgnoreCase(attributeName))
            this.formId = attributeValue;

        if ("disabledFields".equalsIgnoreCase(attributeName))
            this.disabledFields = attributeValue;

        if ("fieldDefs".equalsIgnoreCase(attributeName))
            this.fieldDefs = attributeValue;

    }

}
